@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use OptArgs;
 use lib 'lib';
-our $VERSION = '0.0.3';
+our $VERSION = '0.0.2';
 
 $OptArgs::COLOUR = 1;
 
@@ -44,14 +44,13 @@ sub run {
 
     die $@ unless eval "require $opts->{class};";
 
-    my $initial = do { my @tmp = split( /::/, $opts->{class} ) };
+    my $initial = scalar split( /::/, $opts->{class} );
     my $indent = $opts->{spacer} x $opts->{indent};
 
     binmode( STDOUT, ':encoding(utf8)' );
 
     foreach my $cmd ( OptArgs::_cmdlist( $opts->{class} ) ) {
-        my $length = do { my @tmp = split( /::/, $cmd ) }
-          - $initial;
+        my $length = scalar split( /::/, $cmd ) - $initial;
         my $space = $indent x $length;
 
         unless ( $opts->{full} ) {
@@ -84,7 +83,7 @@ App::optargs - implementation of the optargs(1) command
 
 =head1 VERSION
 
-0.0.3 Development release.
+0.0.2 Development release.
 
 =head1 SYNOPSIS
 
